@@ -47,7 +47,7 @@ def upload_app_to_cloudshell(cs_api, reservation_id, app_name, app_xml_content,
 
     fh = open(display_image_file, "wb")
     if display_image_result is not None:
-        fh.write(display_image_result)
+        fh.write(display_image_result.decode('base64'))
     else:
         fh.write(vm_image.decode('base64'))
     fh.close()
@@ -68,8 +68,8 @@ def upload_app_to_cloudshell(cs_api, reservation_id, app_name, app_xml_content,
     result = requests.post("http://{}:9000/API/Package/ImportPackage".format(server),
                            headers={"Authorization": "Basic {}".format(authentication_code[1:-1])},
                            files={"QualiPackage": zip_content})
+    cs_api.WriteMessageToReservationOutput(reservation_id, result.content)
     if result.status_code >= 300:
-        cs_api
         return result.content
     else:
         return None
\ No newline at end of file
